Array Properties
################

The LibRapid Array type stores a lot of additional information about the data it stores.
While this data is used internally, it is often useful to access some of the array's
properties when doing calculations, which is why LibRapid provides a simple interface to
access this data.

.. toctree::
	:maxdepth: 2
	:glob:

	array_property_ndim
	array_property_extent
	array_property_stride
	array_property_isScalar
	array_property_createRaw
	array_property_dtype
	array_property_location
	array_property_len
